#include "daemon.h"

int main(int argc, char *argv[]) {
    QCoreApplication::setOrganizationName("linfati");
    QCoreApplication::setOrganizationDomain("linfati.com");
    QCoreApplication::setApplicationName("GoogleLatitude");

    QCoreApplication app(argc, argv);

    if ( app.arguments().contains(QString("--init")) ) {
        QSettings set;
        if ( ! set.value("daemon",false).toBool() ) {
            qDebug() << "No Daemon mode enable";
            return 0;
        }
    }

    Daemon demonio;
    Q_UNUSED(demonio);

    return app.exec();
}
